Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(93)

Unified Diff: android_webview/native/aw_contents.cc

Issue 707173004: Refactor Autofill for out of process iframes (OOPIF). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: mem leak Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: android_webview/native/aw_contents.cc
diff --git a/android_webview/native/aw_contents.cc b/android_webview/native/aw_contents.cc
index 969b2af7684a0966d02f0f3684a0a193ae5188c7..50c6b36c63a30430417122e30e288c8c59ee4d3c 100644
--- a/android_webview/native/aw_contents.cc
+++ b/android_webview/native/aw_contents.cc
@@ -43,7 +43,7 @@
#include "base/pickle.h"
#include "base/strings/string16.h"
#include "base/supports_user_data.h"
-#include "components/autofill/content/browser/content_autofill_driver.h"
+#include "components/autofill/content/browser/content_autofill_driver_factory.h"
#include "components/autofill/core/browser/autofill_manager.h"
#include "components/autofill/core/browser/webdata/autofill_webdata_service.h"
#include "components/data_reduction_proxy/core/browser/data_reduction_proxy_settings.h"
@@ -72,7 +72,7 @@
struct AwDrawSWFunctionTable;
-using autofill::ContentAutofillDriver;
+using autofill::ContentAutofillDriverFactory;
using autofill::AutofillManager;
using base::android::AttachCurrentThread;
using base::android::ConvertJavaStringToUTF16;
@@ -241,7 +241,7 @@ void AwContents::SetSaveFormData(bool enabled) {
InitAutofillIfNecessary(enabled);
// We need to check for the existence, since autofill_manager_delegate
// may not be created when the setting is false.
- if (ContentAutofillDriver::FromWebContents(web_contents_.get())) {
+ if (AwAutofillClient::FromWebContents(web_contents_.get())) {
AwAutofillClient::FromWebContents(web_contents_.get())->
SetSaveFormData(enabled);
}
@@ -257,17 +257,16 @@ void AwContents::InitAutofillIfNecessary(bool enabled) {
// Do not initialize if the feature is not enabled.
if (!enabled)
return;
// Check if the autofill driver already exists.
content::WebContents* web_contents = web_contents_.get();
- if (ContentAutofillDriver::FromWebContents(web_contents))
+ if (ContentAutofillDriverFactory::FromWebContents(web_contents))
return;
AwBrowserContext::FromWebContents(web_contents)->
CreateUserPrefServiceIfNecessary();
AwAutofillClient::CreateForWebContents(web_contents);
- ContentAutofillDriver::CreateForWebContentsAndDelegate(
- web_contents,
- AwAutofillClient::FromWebContents(web_contents),
+ ContentAutofillDriverFactory::CreateForWebContentsAndDelegate(
+ web_contents, AwAutofillClient::FromWebContents(web_contents),
base::android::GetDefaultLocale(),
AutofillManager::DISABLE_AUTOFILL_DOWNLOAD_MANAGER);
}
@@ -257,17 +257,16 @@ void AwContents::InitAutofillIfNecessary(bool enabled) {
if (!enabled)
return;
- // Check if the autofill driver already exists.
+ // Check if the autofill driver factory already exists.
content::WebContents* web_contents = web_contents_.get();
« no previous file with comments | « android_webview/native/aw_autofill_client.cc ('k') | android_webview/renderer/aw_content_renderer_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698